@@ -1,3 +1,8 @@
+class RequestMock(object):
+
+    def __init__(self, path="/"):
+        self.path = path
+
 class ResponseMock(dict):
 
     def __init__(self, *args, **kwargs):
@@ -6,4 +11,3 @@ class ResponseMock(dict):
 
     status_code = 200
     content = "<html>   <body>some text here</body>    </html>"
-
